@@ -118,20 +118,20 @@ impl ToSVG for Option<Style> {
         self.as_ref()
             .map(|v| {
                 Ok(format!(
-                    r#"style="{fill}{stroke}""#,
+                    r#"{fill} {stroke}"#,
                     fill = v.fill.to_svg()?,
                     stroke = v.stroke.to_svg()?,
                 ))
             })
-            .unwrap_or(Ok(String::new()))
+            .unwrap_or_else(|| Ok(String::new()))
     }
 }
 
 impl ToSVG for Option<Fill> {
     fn to_svg(&self) -> Result<String, Box<dyn std::error::Error>> {
         match self {
-            Some(Fill::Color(c)) => Ok(format!("fill:{};", c.to_svg()?)),
-            None => Ok(format!("fill:none;")),
+            Some(Fill::Color(c)) => Ok(format!("fill='{}'", c.to_svg()?)),
+            None => Ok("fill='none'".to_string()),
         }
     }
 }
@@ -140,7 +140,7 @@ impl ToSVG for Option<Stroke> {
     fn to_svg(&self) -> Result<String, Box<dyn std::error::Error>> {
         match self {
             Some(Stroke::Full { color, width }) => Ok(format!(
-                "stroke:{};stroke-width:{};",
+                "stroke='{}' stroke-width='{}'",
                 color.to_svg()?,
                 width
             )),
@@ -150,7 +150,7 @@ impl ToSVG for Option<Stroke> {
                 on,
                 off,
             }) => Ok(format!(
-                "stroke:{};stroke-width:{};stroke-dasharray:{},{};",
+                "stroke='{}' stroke-width='{}' stroke-dasharray='{},{}'",
                 color.to_svg()?,
                 width,
                 on,
@@ -220,7 +220,7 @@ mod tests {
                 .with_align(TextAlign::Center),
         );
 
-        let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" style="fill:#FF0000;">hello world</text>"#;
+        let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" fill='#FF0000' >hello world</text>"#;
         let drawing_svg = format!(r#"<svg viewBox="-0 -0 0 0">{}</svg>"#, text_svg);
 
         assert_eq!(drawing.shapes()[0].to_svg().unwrap(), text_svg);
@@ -235,7 +235,7 @@ mod tests {
                 .to(vec2(20., 20.))
                 .with_fill(Fill::Color(Color::U32(0xFF0000))),
         );
-        let line_svg = r#"<line x1="10" y1="10" x2="20" y2="20" style="fill:#FF0000;"/>"#;
+        let line_svg = r#"<line x1="10" y1="10" x2="20" y2="20" fill='#FF0000' />"#;
         let drawing_svg = format!(r#"<svg viewBox="-0 -0 0 0">{}</svg>"#, line_svg);
         assert_eq!(drawing.shapes()[0].to_svg().unwrap(), line_svg);
         assert_eq!(drawing.to_svg().unwrap(), drawing_svg);
